netapp_ontap.models.nvme_namespace_location API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nvme_namespace_location`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NvmeNamespaceLocationSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeNamespaceLocation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `namespace GET POST`

    The base name component of the NVMe namespace. Valid in POST.
    If properties `name` and `location.namespace` are specified in the same request, they must refer to the base name.
    NVMe namespaces do not support rename.

    Example: namespace1

  `qtree GET POST`

    The qtree field of the nvme_namespace_location.

  `volume GET POST`

    The volume field of the nvme_namespace_location.